/******************************************************************************
* Sdl Gui FrameWork (SGFW) : GUI Environment for SDL
* Copyright (C) 2007, Alexander Roper
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
* 
* Alexander Roper
* minirop@peyj.com
******************************************************************************/

#include "GWidget.h"

GWidget::GWidget(GWidget* v_parent)
{
	surf = SDL_CreateRGBSurface(SDL_SWSURFACE, 100, 100, 32, 0, 0, 0, 0);
	pos.x = 0;
	pos.y = 0;
	pos.h = 0;
	pos.w = 0;
	parent = v_parent;
	if(v_parent == 0)
	{
		gApp->AddChild(this);
	}
	bg.r = 0;
	bg.g = 0;
	bg.b = 0;
}

GWidget::~GWidget()
{
	if(surf != NULL)
		SDL_FreeSurface(surf);
}

void GWidget::paint()
{
	for(std::vector<GWidget*>::iterator it = child.begin();it != child.end();++it)
	{
		(*it)->update();
	}
	
	if(parent != NULL)
		SDL_BlitSurface(surf,NULL,parent->surf,&pos);
	else
		SDL_BlitSurface(surf,NULL,__root_surface,&pos);
}

void GWidget::update()
{
	SDL_FillRect(surf,NULL,SDL_MapRGB(surf->format,bg.r,bg.g,bg.b));
	paint();
}

void GWidget::resize(int h,int w)
{
	if(surf != NULL)
		SDL_FreeSurface(surf);
	surf = SDL_CreateRGBSurface(SDL_SWSURFACE, h, w, 32, 0, 0, 0, 0);
}

void GWidget::setPos(int x,int y)
{
	pos.x = x;
	pos.y = y;
}

void GWidget::setBackgroundColor(int r,int g,int b)
{
	SDL_Color t = {r,g,b,0};
	bg = t;
}
